document.getElementById('oathForm').addEventListener('submit', function(event) {
    event.preventDefault(); // Prevent default form submission

    const name = document.getElementById('name').value; // Get the name from the input

    // Load the SVG template
    fetch('template.svg') // Ensure this path points to your SVG file
        .then(response => {
            if (!response.ok) {
                throw new Error('Network response was not ok');
            }
            return response.text();
        })
        .then(svgText => {
            // Replace "Name Here" and "Signature" with the actual name
            const updatedSvg = svgText.replace(/Name Here/g, name).replace(/Signature/g, name);

            // Create a Blob from the updated SVG and convert it to a data URL
            const svgBlob = new Blob([updatedSvg], { type: 'image/svg+xml;charset=utf-8' });
            const url = URL.createObjectURL(svgBlob);

            // Create an image and load the SVG
            const img = new Image();
            img.onload = function() {
                // Create a canvas to draw the image on
                const canvas = document.createElement('canvas');
                canvas.width = 600; // Set canvas width
                canvas.height = 838; // Set canvas height
                const ctx = canvas.getContext('2d');
                ctx.drawImage(img, 0, 0);

                // Convert canvas to JPG
                const jpgData = canvas.toDataURL('image/jpeg');

                // Set the inner HTML of the SVG container
                document.getElementById('svgContainer').innerHTML = `<img src="${jpgData}" alt="Preview">`;

                // Show the SVG and download button
                document.getElementById('oathContainer').style.display = 'block';

                // Store JPG data URL for downloading
                document.getElementById('downloadBtn').onclick = function() {
                    const a = document.createElement('a');
                    a.href = jpgData;
                    a.download = 'oath_form.jpg';
                    document.body.appendChild(a);
                    a.click();
                    document.body.removeChild(a);
                };

                // Share button functionality
                document.getElementById('shareBtn').onclick = function() {
                    // Send the image to the server
                    fetch('upload.php', {
                        method: 'POST',
                        headers: {
                            'Content-Type': 'application/x-www-form-urlencoded',
                        },
                        body: 'image=' + encodeURIComponent(jpgData)
                    })
                    .then(response => response.json())
                    .then(data => {
                        if (data.status === 'success') {
                            const savedImageUrl = data.filePath;
                            const message = "Help spread the word! Share this oath to promote awareness and safeguard our digital presence.";

                            // Create share links with the saved image URL
                            const facebookUrl = `https://www.facebook.com/sharer/sharer.php?u=${encodeURIComponent(savedImageUrl)}&quote=${encodeURIComponent(message)}`;
                            const whatsappUrl = `https://wa.me/?text=${encodeURIComponent(message)} ${encodeURIComponent(savedImageUrl)}`;

                            // Open share links in new tabs
                            window.open(facebookUrl, '_blank');
                            window.open(whatsappUrl, '_blank');
                        } else {
                            console.error('Error saving image:', data.message);
                        }
                    })
                    .catch(error => console.error('Error:', error));
                };

                URL.revokeObjectURL(url); // Clean up the URL
            };
            img.src = url; // Set the source of the image to the URL of the SVG Blob
        })
        .catch(error => console.error('Error loading SVG:', error));
});
